==> kikd-0.0.96.tgz: package/readme.md <==
<p align="center">
    <a href="https://github.com/RayBenefield/kikd">
        <img src="https://screenshotlayer.com/images/assets/placeholder.png" alt="KI/KD"/>
    </a>
    <br />
    <sub><em>Placeholder until a logo is designed</em></sub>
</p>

# KI/KD

***Pronounced:*** */kɪkt/*

Continuous Integration and Continuous Deployment standards for Open Sourced NPM Tools.

---


## NOTICE: Active Development

**KI/KD** is still in its early stages of development. Feel free to watch this
project as it grows and use the
[**issues**](https://github.com/RayBenefield/kikd/issues) section to
put in any questions or ideas you may have.

*Nothing in this project promises to be stable until we reach `v0.1.0`.*

---


## Work Log

**KI/KD** is developed with an agile methodology that I'm currently developing
called **DEX**. This methodology revolves around doing 25 minute work sessions
(inspired by the [**Pomodoro
Technique**](https://lifehacker.com/productivity-101-a-primer-to-the-pomodoro-technique-1598992730))
and then logging what was done in that session with a work log entry.

**You can find all of the work log entries here:** [`./docs/worklog.md`](./docs/worklog.md)

---


## Inception

**KI/KD** came around as a result of my work on **Transmutation** to improve its
maintainability as an open source tool. I've been scouring the interwebz for
standards that are being used by project maintainers and I've discovered
wonderful concepts like **Conventional Changelogs**, **Monorepos**, **Auto
Deployments on Travis**, etc. There are so many wonderful tools out there that
it takes a lot to really get a repo setup. I've been working on
**Transmutation** quality for about 2 weeks now and it should be faster and more
standard. There are things I agree with in the community, but also things I
prefer a different way.

**KI/KD** shoots to be my own ***EXTREMELY*** opinionated standards for setting
up **{K,C}ontinuous Integration** and **{K,C}ontinuous Deployment** for my own
open sourced tools that I publish on NPM. I'm no expert on open source, I've
barely contributed, but I love to code every day and improve my own skillset and
automation regularly at the jobs that I have and I'm trying to find the best way
for me to speed up my development and publishing. My goal is to have projects be
able to have full CI/CD within a single **Pomodoro** session (25 minutes)
without copying-pasting.

---


## Rough Roadmap

**KI/KD** plans to be a constantly growing standard so right now the current
dump for brainstorming and ideas on what to tackle in the future are all in a
single markdown document to stay organized and when the time comes then a new
idea can be turned into an issue and tackled by a contributor.

**You can find the rough roadmap here:**
[`./docs/rough-roadmapping.md`](./docs/rough-roadmapping.md)

---


## Install

**Pick one** - *Listed in order of recommendation*

```bash
yarn add kikd
npm i -S kikd
npm install --save kikd
```

---


## Usage

<p align="center">
    <img src="https://media.giphy.com/media/WKAwHGV5Hu3vi/giphy.gif" alt="Under Construction"/>
</p>

---


## Team

|[![Ray Benefield](http://gravatar.com/avatar/e931b13306ea1022549766266727f789?s=144)](https://github.com/RayBenefield) |
|:---:|
|[Ray Benefield](https://raybenefield.com) |
|[Chief Architect](https://en.wikipedia.org/wiki/Software_architect) |

---


## License

MIT © [Ray Benefield](https://raybenefield.com)

==> kikd-0.0.179.tgz: package/readme.md <==
<p align="center">
    <a href="https://github.com/RayBenefield/dev-xp/tree/master/src/node_modules/kikd">
        <img src="https://screenshotlayer.com/images/assets/placeholder.png" alt="KI/KD"/>
    </a>
    <br />
    <sub><em>Placeholder until a logo is designed</em></sub>
</p>

# KI/KD

***Pronounced:*** */kɪkt/*

Continuous Integration and Continuous Deployment standards for Open Sourced NPM Tools.

---


## NOTICE: Active Development

**KI/KD** is still in its early stages of development. Feel free to watch this
project as it grows and use the
[**issues**](https://github.com/RayBenefield/dev-xp/projects/1) section to
put in any questions or ideas you may have.

*Nothing in this project promises to be stable until we reach `v0.1.0`.*

---


## Work Log

**KI/KD** is developed with an agile methodology that I'm currently developing
called **DEX**. This methodology revolves around doing 25 minute work sessions
(inspired by the [**Pomodoro
Technique**](https://lifehacker.com/productivity-101-a-primer-to-the-pomodoro-technique-1598992730))
and then logging what was done in that session with a work log entry.

**You can find all of the work log entries here:** [`./docs/worklog.md`](./docs/worklog.md)

---


## Inception

**KI/KD** came around as a result of my work on **Transmutation** to improve its
maintainability as an open source tool. I've been scouring the interwebz for
standards that are being used by project maintainers and I've discovered
wonderful concepts like **Conventional Changelogs**, **Monorepos**, **Auto
Deployments on Travis**, etc. There are so many wonderful tools out there that
it takes a lot to really get a repo setup. I've been working on
**Transmutation** quality for about 2 weeks now and it should be faster and more
standard. There are things I agree with in the community, but also things I
prefer a different way.

**KI/KD** shoots to be my own ***EXTREMELY*** opinionated standards for setting
up **{K,C}ontinuous Integration** and **{K,C}ontinuous Deployment** for my own
open sourced tools that I publish on NPM. I'm no expert on open source, I've
barely contributed, but I love to code every day and improve my own skillset and
automation regularly at the jobs that I have and I'm trying to find the best way
for me to speed up my development and publishing. My goal is to have projects be
able to have full CI/CD within a single **Pomodoro** session (25 minutes)
without copying-pasting.

---


## Rough Roadmap

**KI/KD** plans to be a constantly growing standard so right now the current
dump for brainstorming and ideas on what to tackle in the future are all in a
single markdown document to stay organized and when the time comes then a new
idea can be turned into an issue and tackled by a contributor.

**You can find the rough roadmap here:**
[`./docs/rough-roadmapping.md`](./docs/rough-roadmapping.md)

---


## Install

**Pick one** - *Listed in order of recommendation*

```bash
yarn add kikd --dev
npm i kikd -D
npm install kikd --save-dev 
```

---


## Usage

<p align="center">
    <img src="https://media.giphy.com/media/WKAwHGV5Hu3vi/giphy.gif" alt="Under Construction"/>
</p>

---


## Prior Art

Thank you to all of the projects that inspired
[**KI/KD**](https://github.com/RayBenefield/dev-xp/tree/master/src/node_modules/kikd):

 - [**Alle**](https://github.com/boennemann/alle) - *Thank you for pitching a
   this powerful monorepo structure*
 - [**PouchDB**](https://github.com/pouchdb/pouchdb) - *Thank you for being the
   example [**Alle**](https://github.com/boennemann/alle) repo*
 - [**Lerna**](https://lernajs.io/) - *Thank you for being THE monorepo tool*
 - [**Babel**](https://babeljs.io/) - *Thank you for being an amazing
   influential monorepo*
 - [**Bolt Pkg**](http://boltpkg.com/) - *Thank you for being another monorepo
   toll example*
 - [**Create React App**](https://github.com/facebook/create-react-app/) -
   *Thank you for your awesome opinionated scaffolding example*
 - [**Angular.js**](https://angularjs.org/) - *Thank you for designing the
   original commit style*
 - [**Conventional Commits**](https://conventionalcommits.org/) - *Thank you for
   laying down the foundation for useful commit messages*
 - [**Commitlint**](http://marionebl.github.io/commitlint/#/) - *Thank you for
   inspiring the enforcement of commit standards*
 - [**Commitizen**](https://github.com/commitizen/) - *Thank you for
   demonstrating a solid example of automation for commits*
 - [**Semantic Release**](https://github.com/semantic-release/semantic-release)
   *Thank you for demonstrating the handling of auto-versioning on CI*
 - [**Semantic Versioning**](https://semver.org/) - *Thank you for setting a
   standard of versioning packages*

---


## Team

|[![Ray Benefield](http://gravatar.com/avatar/e931b13306ea1022549766266727f789?s=144)](https://github.com/RayBenefield) |
|:---:|
|[Ray Benefield](https://raybenefield.com) |
|[Chief Architect](https://en.wikipedia.org/wiki/Software_architect) |

---


## License

MIT © [Ray Benefield](https://raybenefield.com)
